Summary:    A set of system configuration and setup files
Name:       setup
Version:    2.7.25
Release:    %mkrel 3
License:    Public Domain
Group:      System/Base
Url:        https://gitweb.mageia.org/software/setup
# https://gitweb.mageia.org/software/setup
# NO PATCH ALLOWED, COMMIT IN GIT!!!!
Source0:     %{name}-%{version}.tar.xz
BuildArch: noarch
BuildRequires: bash tcsh perl
# prevent the shell to fail running post script:
Requires(posttrans): glibc
# for backward compatibility, to remove when other packages correctly require run-parts directly:
Requires:   run-parts

%description
The setup package contains a set of very important system
configuration and setup files, such as passwd, group,
profile and more.

You should install the setup package because you will
find yourself using its many features for system
administration.


%prep
%setup -q
./shadowconvert.sh

%check
# Run any sanity checks.
%__make check

%install
%make_install

%files
%doc NEWS
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/passwd
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/group
%verify(not md5 size mtime) %attr(0440,root,shadow) %config(noreplace) %{_sysconfdir}/shadow
%verify(not md5 size mtime) %attr(0440,root,shadow) %config(noreplace) %{_sysconfdir}/gshadow
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/subuid
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/subgid
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/fstab
%config(noreplace) %{_sysconfdir}/services
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/resolv.conf
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts
%config(noreplace) %{_sysconfdir}/filesystems
%config(noreplace) %{_sysconfdir}/host.conf
%config(noreplace) %{_sysconfdir}/hosts.allow
%config(noreplace) %{_sysconfdir}/hosts.deny
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/motd
%config(noreplace) %{_sysconfdir}/printcap
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/inputrc
%config(noreplace) %{_sysconfdir}/protocols
%config(noreplace) %{_sysconfdir}/profile
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/shells
%attr(0644,root,root) %config(missingok,noreplace) %{_sysconfdir}/securetty
%config(noreplace) %{_sysconfdir}/csh.login
%config(noreplace) %{_sysconfdir}/csh.cshrc
%config(noreplace) %{_sysconfdir}/networks
%ghost %verify(not md5 size mtime) /var/log/lastlog

%posttrans -p <lua>
-- fix owner group as there is no shadow group available during the initial installation
shadowfiles = {'shadow', 'shadow-', 'gshadow', 'gshadow-'}
for i, file in ipairs(shadowfiles) do
  if posix.access("/etc/" .. file, "f") then
    f = posix.stat("/etc/" .. file)
    if f.gid ~= "shadow" then
      posix.chown("/etc/" .. file, "root", "shadow")
    end
  end
end

cfgfiles = {'fstab', 'group', 'gshadow', 'hosts', 'passwd', 'resolv.conf', 'shadow'}
for i, file in ipairs(cfgfiles) do
  if posix.stat("/etc/" .. file .. ".rpmnew") then
    os.remove("/etc/" .. file .. ".rpmnew")
  end
end

if posix.access("/usr/sbin/nscd", "x") then
  rpm.execute("nscd", "-i", "passwd", "-i", "group")
end


%changelog
* Sun Apr 28 2024 wally <wally> 2.7.25-3.mga10
+ Revision: 2061405
- drop old %%triggerpostun and %%triggerun scriptlets
- make sure (g)shadow and (g)shadow- file owner group is shadow
- remove unwanted .rpmnew files

* Mon Mar 21 2022 umeabot <umeabot> 2.7.25-2.mga9
+ Revision: 1812989
- Mageia 9 Mass Rebuild

* Wed Jul 29 2020 ovitters <ovitters> 2.7.25-1.mga8
+ Revision: 1609555
- new version: 2.7.25
- hosts: align additional hostnames as per Fedora (some package tests/checks assume those hostnames exist)
- inputrc: add missing keybindings from Fedora and structure file in similar order, no keybindings have been removed
- protocols: sync with Fedora
- profile: UID_MIN (normal user UIDS) start at 1000, not 500
- profile: set HISTCONTROL to ignoreboth if it was ignorespace, else fall back to ignoredups
- profile: provide a way how to override set envvars through /etc/profile.d/sh.local file
- profile: do show messages from /etc/profile.d/* in interactive shell, login shells
- profile: use hostnamectl instead of hostname
- services: sync with Fedora
- shells: sync with Fedora (adds redundant /usr/bin/sh, /usr/bin/bash)
- {subuid,subgid}: add basic empty files for docker, as per Fedora
- networks: move from initscripts to setup package
- order the files in similar order as Fedora spec, plus fix url

* Sat Feb 15 2020 umeabot <umeabot> 2.7.24-4.mga8
+ Revision: 1524020
- Mageia 8 Mass Rebuild

* Sun Mar 24 2019 wally <wally> 2.7.24-3.mga7
+ Revision: 1379918
- remove unsupported entries from /etc/host.conf added by msec < 2.5 (mga#21621)

* Wed Sep 19 2018 umeabot <umeabot> 2.7.24-2.mga7
+ Revision: 1275415
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Update make macros

* Thu Sep 01 2016 tv <tv> 2.7.24-1.mga6
+ Revision: 1049676
- add BRs for testsuite
- do not try to create lastlog in %%posttrans as we already package it
- run checks
- clean spec
- merge patches & shadowconvert.sh into git
- sync services+protocols with FC
- hosts: add a default IPv6 localhost entry
- filesystem:
  o add asterisk to honor /proc/filesystems
  o list ext[34] fs

* Fri Feb 19 2016 umeabot <umeabot> 2.7.21-7.mga6
+ Revision: 969337
- Mageia 6 Mass Rebuild

* Fri Aug 21 2015 tmb <tmb> 2.7.21-6.mga6
+ Revision: 867886
- rebuild for new gcc

* Wed Apr 08 2015 akien <akien> 2.7.21-5.mga5
+ Revision: 819875
- Delete .rpmnew files in %%triggerun instead of %%post
- Bump %%triggerun version to also remove .rpmnew files from already-updated systems
- Use lua in the %%post script as shell might not be available at install time
- Delete potential .rpmnew files in %%post to ease upgrades (mga#14266, mga#14516)

* Fri Mar 20 2015 akien <akien> 2.7.21-4.mga5
+ Revision: 819034
- Fix permissions for /etc/{,g}shadow{,-} (mga#14516)

* Wed Oct 15 2014 umeabot <umeabot> 2.7.21-3.mga5
+ Revision: 744206
- Second Mageia 5 Mass Rebuild
+ eatdirt <eatdirt>
- Change permission on (g)shadow files mga#14194
+ akien <akien>
- New tarball, add /usr/local/games to the PATH in /etc/profile

* Tue Sep 16 2014 umeabot <umeabot> 2.7.20-10.mga5
+ Revision: 689120
- Mageia 5 Mass Rebuild

* Sat Dec 14 2013 colin <colin> 2.7.20-9.mga4
+ Revision: 556778
- Fix patch application (due to rpm bug) mga#11980

* Thu Dec 12 2013 pterjan <pterjan> 2.7.20-8.mga4
+ Revision: 556507
- Install the created shadow and gshadow files into /etc
- Fix architecture tag, so that it can be built
+ tv <tv>
- make it noarch

* Thu May 23 2013 colin <colin> 2.7.20-6.mga4
+ Revision: 424805
- Nuke the 'shutdown' and 'halt' users. They serve no purpose these days (mga#7389)

* Mon Apr 22 2013 tv <tv> 2.7.20-5.mga3
+ Revision: 410770
- convert to shadow at build time and package /etc/{g,}shadow
  thus fixing "su: Insufficient credentials to access authentication data"
  errors in post scripts between setup & basesystem-minimal installations

* Mon Apr 01 2013 tv <tv> 2.7.20-4.mga3
+ Revision: 407081
- drop old TCB conversion in %%post and adding old new groups,
  thus enabling setup to be installed earlier in transactions,
  thus fixing bogus file permissions (mga#9326)

* Wed Jan 23 2013 fwang <fwang> 2.7.20-3.mga3
+ Revision: 391543
- update rpm group

* Mon Jan 14 2013 umeabot <umeabot> 2.7.20-2.mga3
+ Revision: 381948
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Mar 15 2012 kamil <kamil> 2.7.20-1.mga2
+ Revision: 223507
- remove run-parts from this package, it's packaged separately

* Thu Mar 15 2012 guillomovitch <guillomovitch> 2.7.19-1.mga2
+ Revision: 223489
- drop old migration trigger
- new version

* Tue Oct 25 2011 dmorgan <dmorgan> 2.7.18-5.mga2
+ Revision: 157976
- Really do not package mtab
- Remove unneeded rpmstuff
- Remove occurency to mtab ( tks to sander85)
- mtab is owned by util-linux now

* Wed Jan 12 2011 blino <blino> 2.7.18-3.mga1
+ Revision: 6778
- update url
- remove old conflicts
- imported package setup


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 2.7.18-2mdv2011.0
+ Revision: 607533
- rebuild

* Thu Dec 31 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.7.18-1mdv2010.1
+ Revision: 484524
- new version

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.7.17-2mdv2010.0
+ Revision: 427069
- rebuild

* Sat Apr 11 2009 Gustavo De Nardin <gustavodn@mandriva.com> 2.7.17-1mdv2009.1
+ Revision: 366419
- 2.7.17
  - stop csh from sourcing /etc/profile.d/* on non-interactive shells
    (bug #49407, comment 6)

* Fri Jan 09 2009 Frederic Crozat <fcrozat@mandriva.com> 2.7.16-1mdv2009.1
+ Revision: 327455
- Release 2.7.16 :
 - add dialout group, needed by latest udev, replace uucp group for serial stuff, just like Debian

* Wed Jan 07 2009 Pixel <pixel@mandriva.com> 2.7.15-1mdv2009.1
+ Revision: 326531
- 2.7.15: handle control + left/right arrow in gnome-terminal (#36287)

* Wed Dec 17 2008 Frederic Crozat <fcrozat@mandriva.com> 2.7.14-1mdv2009.1
+ Revision: 315121
- Release 2.7.14 :
 - fix warning in run-parts
 - configure inputrc to add trailing / to directories symlink (instead of patching bash)

* Sat Jul 12 2008 Olivier Thauvin <nanardon@mandriva.org> 2.7.13-1mdv2009.0
+ Revision: 234201
- 2.7.13: add tty0 to securetty for uml

* Thu May 22 2008 Vincent Danen <vdanen@mandriva.com> 2.7.12-3mdv2009.0
+ Revision: 210051
- use %%_pre_groupadd instead of groupadd directly to dynamically assign gid's on upgrades, since those gid's may already have been taken

* Sun May 18 2008 Vincent Danen <vdanen@mandriva.com> 2.7.12-2mdv2009.0
+ Revision: 208736
- create shadow, chkpwed, and auth groups in %%pre if they don't already exist in the system

* Wed May 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 2.7.12-1mdv2009.0
+ Revision: 207315
- new version

* Fri Mar 28 2008 Pixel <pixel@mandriva.com> 2.7.11-3mdv2008.1
+ Revision: 190933
- require run-parts for backward compatibility until other packages correctly
  require it directly

* Fri Mar 28 2008 Pixel <pixel@mandriva.com> 2.7.11-2mdv2008.1
+ Revision: 190867
- run-parts is moved to package run-parts

* Mon Jan 28 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 2.7.11-1mdv2008.1
+ Revision: 159330
- New upstream: 2.7.11. Closes: #34841
- Update URL tag.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Dec 12 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.7.10-1mdv2008.1
+ Revision: 119058
- new version

* Tue Sep 11 2007 Oden Eriksson <oeriksson@mandriva.com> 2.7.9-2mdv2008.0
+ Revision: 84515
- rebuild

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - new release


* Mon Mar 19 2007 Pixel <pixel@mandriva.com> 2.7.8-2mdv2007.1
+ Revision: 146582
- handle upgrade without loosing /etc/exports

* Fri Mar 09 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.7.8-1mdv2007.1
+ Revision: 138765
- new version

* Wed Mar 07 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.7.7-1mdv2007.1
+ Revision: 134254
- new version
- macrozification

* Fri Feb 16 2007 Pixel <pixel@mandriva.com> 2.7.5-3mdv2007.1
+ Revision: 121670
- explicitly provide /usr/bin/run-parts (required by crontabs)

* Thu Feb 15 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.7.5-2mdv2007.1
+ Revision: 121545
- fix requires

* Thu Jan 25 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.7.5-1mdv2007.1
+ Revision: 113344
- new version (should fix #24915 and #19822)

* Mon Jan 08 2007 Warly <warly@mandriva.com> 2.7.4-1mdv2007.1
+ Revision: 105933
- update tarball and spec for version 2.7.4

  + Michael Scherer <misc@mandriva.org>
    - Import setup

* Sun Jun 04 2006 Olivier Thauvin <nanardon@mandriva.org> 2.7.3-1mdv2007.0
- provide a /etc/{fstab,mtab,resolv.conf}, for chroot
- prevent lastlog to be overwritten

* Wed May 17 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.7.2-1mdk
- add missing prereq
- fix installing in urpmi --root

* Sat May 13 2006 Stefan van der Eijk <stefan@eijk.nu> 2.7.1-7mdk
- rebuild for sparc

* Fri Mar 03 2006 Oden Eriksson <oeriksson@mandriva.com> 2.7.1-6mdk
- nuke the iana-etc stuff, too hard to maintain, too many conflicts.

* Fri Mar 03 2006 Oden Eriksson <oeriksson@mandriva.com> 2.7.1-5mdk
- add squid port aliases (neoclust)

* Fri Mar 03 2006 Oden Eriksson <oeriksson@mandriva.com> 2.7.1-4mdk
- add ircd ports
- add svnserve port aliases
- add swat ports aliases (#21412)

* Wed Jan 25 2006 Oden Eriksson <oeriksson@mandriva.com> 2.7.1-3mdk
- removed duplicated aliases
- ship the original protocols and services in the doc section for reference

* Tue Jan 24 2006 Oden Eriksson <oeriksson@mandriva.com> 2.7.1-2mdk
- merged the iana-etc package from contrib into this package

* Wed Dec 07 2005 Frederic Lepied <flepied@mandriva.com> 2.7.1-1mdk
- added mysql and asterix ports (Oden)
- added Jabber and bittorrent ports (Pablo)

* Thu Sep 01 2005 Leonardo Chiquitto Filho <chiquitto@mandriva.com> 2.7-2mdk
- bashrc to run /etc/profile.d scripts just with supported shells (ticket #16515)

* Wed Aug 24 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 2.7-1mdk
- varargs fixes to run-parts

* Wed Mar 09 2005 Warly <warly@mandrakesoft.com> 2.6-1mdk
- add hpfs in filesystems as it seems that this filesystem is not probed
- add group tape (21) in group as udev is using it
- correct invalid syntax in profile for sh without bash extensions
- add requires on shadow-utils for post scripts

* Wed Feb 09 2005 Frederic Lepied <flepied@mandrakesoft.com> 2.5-1mdk
- added some missing entries (nut, ...) in services
- fixed some rpmlint warnings
- setup.spec, man/Makefile, man/it/Makefile, man/it/run-parts.8,
  man/it/update-passwd.8, man/nl/Makefile: Added Italian man pages;
  enabled Dutch man patches (Pablo)
- man/nl/: run-parts.8, update-passwd.8: Updated Dutch (nl)
  translation by Richard Rasker <mandrake.tips@free.fr> *
  setup/man/nl/ (Reinout van Schouwen)
- inputrc: Redefined PgUp/PgDn so that instead of just cycling
  trough history (like Up/Down arrows already do) it is possible to
  type the beginning of a previous command, then cycle only trough
  matching history entries. (Pablo)

